Coverage report

# Coverage report: 97%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 326 | 9 | 0 | 97%
markupmirror | 17 | 0 | 0 | 100%
markupmirror.exceptions | 2 | 0 | 0 | 100%
markupmirror.feincms | 4 | 0 | 0 | 100%
markupmirror.feincms.models | 16 | 0 | 0 | 100%
markupmirror.fields | 100 | 2 | 0 | 98%
markupmirror.markup | 6 | 0 | 0 | 100%
markupmirror.markup.base | 39 | 0 | 0 | 100%
markupmirror.markup.html | 8 | 0 | 0 | 100%
markupmirror.markup.markdown_ | 22 | 2 | 0 | 91%
markupmirror.markup.plaintext | 12 | 0 | 0 | 100%
markupmirror.markup.restructuredtext | 18 | 2 | 0 | 89%
markupmirror.markup.textile_ | 18 | 2 | 0 | 89%
markupmirror.models | 0 | 0 | 0 | 100%
markupmirror.settings | 8 | 0 | 0 | 100%
markupmirror.urls | 7 | 0 | 0 | 100%
markupmirror.views | 13 | 1 | 0 | 92%
markupmirror.widgets | 36 | 0 | 0 | 100%